<?php

namespace Drupal\groupmenu\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\groupmenu\GroupMenuService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * The group menu settings form.
 */
class GroupMenuSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'groupmenu_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['groupmenu.settings'];
  }

  /**
   * The group menu service.
   *
   * @var \Drupal\groupmenu\GroupMenuService
   */
  protected GroupMenuService $groupMenuService;

  /**
   * {@inheritdoc}
   */
  public function __construct(GroupMenuService $groupMenuService) {
    parent::__construct();

    $this->groupMenuService = $groupMenuService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('groupmenu.menu')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $config = $this->groupMenuService->getConfig();
    if ($config->get('groupmenu_hide_list')) {

      $form['groupmenu_hide_list'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Hide group menus from menu lists'),
        '#description' => $this->t("Hide group menus from default menu lists. (recommended)"),
        '#default_value' => $config->get('groupmenu_hide_list'),
      ];
      return $form;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $form_hide_list = $form_state->getValue('groupmenu_hide_list');
    $this->groupMenuService->setConfig('groupmenu_hide_list', $form_hide_list);
    parent::submitForm($form, $form_state);
  }

}
